Description Usage Arguments Details Value Examples
View source: R/buffer_ovlpts.R
buffer_ovlpts Buffer overlapping points along a
grid.
1 | buffer_ovlpts(spacing, pt.buffer = NULL, bounds, pt.coords)
|
spacing |
numeric of length 1, specifying minimum distance (in units of bounds/pt.coords) that points should be apart. |
pt.buffer |
numeric of length 1, specifying minimum distance (in units of bounds/pt.coords) that points should be away from true locations |
bounds |
either object of class extent, or a numeric vector of length 4, specifying the ymin, ymax, xmin and xmax bounds of the points. |
pt.coords |
Coordinates of points (x,y) |
... |
Not currently in use |
...
A four column data.table specifying the original and buffered point locations
1 2 3 4 | ## Not run:
none yet
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.