Description Usage Arguments Details Value Examples
View source: R/project_layers.R
project_layers Project layers for plotting
1 2 |
proj |
Projection to use. Otherwise defaults to WGS84, centered on the middle of the extent |
extent |
a numeric vector of length 4, specifying the ymin, ymax, xmin and xmax bounds of the map |
geodata |
named list containing geographic data layers. For a layer to be projected and returned, it must have a class of either Raster or Spatial. |
crop.raster |
logical, should rasters be cropped? Speeds things up a lot. |
layers |
vector of geodata names to use. Defaults to all. |
... |
Not currently in use |
...
A four column data.table specifying the original and buffered point locations
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.